import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface ExternalTableConfig extends cdktf.TerraformMetaArguments {
    /**
     * Specifies whether to automatically refresh the external table metadata once, immediately after the external table is created.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/external_table.html#auto_refresh ExternalTable#auto_refresh}
     *
     * @stability stable
     */
    readonly autoRefresh?: boolean;
    /**
     * Specifies the aws sns topic for the external table.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/external_table.html#aws_sns_topic ExternalTable#aws_sns_topic}
     *
     * @stability stable
     */
    readonly awsSnsTopic?: string;
    /**
     * Specifies a comment for the external table.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/external_table.html#comment ExternalTable#comment}
     *
     * @stability stable
     */
    readonly comment?: string;
    /**
     * Specifies to retain the access permissions from the original table when an external table is recreated using the CREATE OR REPLACE TABLE variant.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/external_table.html#copy_grants ExternalTable#copy_grants}
     *
     * @stability stable
     */
    readonly copyGrants?: boolean;
    /**
     * The database in which to create the external table.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/external_table.html#database ExternalTable#database}
     *
     * @stability stable
     */
    readonly database: string;
    /**
     * Specifies the file format for the external table.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/external_table.html#file_format ExternalTable#file_format}
     *
     * @stability stable
     */
    readonly fileFormat: string;
    /**
     * Specifies a location for the external table.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/external_table.html#location ExternalTable#location}
     *
     * @stability stable
     */
    readonly location: string;
    /**
     * Specifies the identifier for the external table;
     *
     * must be unique for the database and schema in which the externalTable is created.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/external_table.html#name ExternalTable#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Specifies any partition columns to evaluate for the external table.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/external_table.html#partition_by ExternalTable#partition_by}
     *
     * @stability stable
     */
    readonly partitionBy?: string[];
    /**
     * Specifies weather to refresh when an external table is created.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/external_table.html#refresh_on_create ExternalTable#refresh_on_create}
     *
     * @stability stable
     */
    readonly refreshOnCreate?: boolean;
    /**
     * The schema in which to create the external table.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/external_table.html#schema ExternalTable#schema}
     *
     * @stability stable
     */
    readonly schema: string;
    /**
     * column block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/external_table.html#column ExternalTable#column}
     *
     * @stability stable
     */
    readonly column: ExternalTableColumn[];
}
/**
 * @stability stable
 */
export interface ExternalTableColumn {
    /**
     * String that specifies the expression for the column. When queried, the column returns results derived from this expression.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/external_table.html#as ExternalTable#as}
     *
     * @stability stable
     */
    readonly as: string;
    /**
     * Column name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/external_table.html#name ExternalTable#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Column type, e.g. VARIANT.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/external_table.html#type ExternalTable#type}
     *
     * @stability stable
     */
    readonly type: string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/snowflake/r/external_table.html snowflake_external_table}.
 *
 * @stability stable
 */
export declare class ExternalTable extends cdktf.TerraformResource {
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/snowflake/r/external_table.html snowflake_external_table} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: ExternalTableConfig);
    private _autoRefresh?;
    /**
     * @stability stable
     */
    get autoRefresh(): boolean;
    /**
     * @stability stable
     */
    set autoRefresh(value: boolean);
    /**
     * @stability stable
     */
    resetAutoRefresh(): void;
    /**
     * @stability stable
     */
    get autoRefreshInput(): boolean | undefined;
    private _awsSnsTopic?;
    /**
     * @stability stable
     */
    get awsSnsTopic(): string;
    /**
     * @stability stable
     */
    set awsSnsTopic(value: string);
    /**
     * @stability stable
     */
    resetAwsSnsTopic(): void;
    /**
     * @stability stable
     */
    get awsSnsTopicInput(): string | undefined;
    private _comment?;
    /**
     * @stability stable
     */
    get comment(): string;
    /**
     * @stability stable
     */
    set comment(value: string);
    /**
     * @stability stable
     */
    resetComment(): void;
    /**
     * @stability stable
     */
    get commentInput(): string | undefined;
    private _copyGrants?;
    /**
     * @stability stable
     */
    get copyGrants(): boolean;
    /**
     * @stability stable
     */
    set copyGrants(value: boolean);
    /**
     * @stability stable
     */
    resetCopyGrants(): void;
    /**
     * @stability stable
     */
    get copyGrantsInput(): boolean | undefined;
    private _database;
    /**
     * @stability stable
     */
    get database(): string;
    /**
     * @stability stable
     */
    set database(value: string);
    /**
     * @stability stable
     */
    get databaseInput(): string;
    private _fileFormat;
    /**
     * @stability stable
     */
    get fileFormat(): string;
    /**
     * @stability stable
     */
    set fileFormat(value: string);
    /**
     * @stability stable
     */
    get fileFormatInput(): string;
    /**
     * @stability stable
     */
    get id(): string;
    private _location;
    /**
     * @stability stable
     */
    get location(): string;
    /**
     * @stability stable
     */
    set location(value: string);
    /**
     * @stability stable
     */
    get locationInput(): string;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    /**
     * @stability stable
     */
    get owner(): string;
    private _partitionBy?;
    /**
     * @stability stable
     */
    get partitionBy(): string[];
    /**
     * @stability stable
     */
    set partitionBy(value: string[]);
    /**
     * @stability stable
     */
    resetPartitionBy(): void;
    /**
     * @stability stable
     */
    get partitionByInput(): string[] | undefined;
    private _refreshOnCreate?;
    /**
     * @stability stable
     */
    get refreshOnCreate(): boolean;
    /**
     * @stability stable
     */
    set refreshOnCreate(value: boolean);
    /**
     * @stability stable
     */
    resetRefreshOnCreate(): void;
    /**
     * @stability stable
     */
    get refreshOnCreateInput(): boolean | undefined;
    private _schema;
    /**
     * @stability stable
     */
    get schema(): string;
    /**
     * @stability stable
     */
    set schema(value: string);
    /**
     * @stability stable
     */
    get schemaInput(): string;
    private _column;
    /**
     * @stability stable
     */
    get column(): ExternalTableColumn[];
    /**
     * @stability stable
     */
    set column(value: ExternalTableColumn[]);
    /**
     * @stability stable
     */
    get columnInput(): ExternalTableColumn[];
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
