import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface FileFormatGrantConfig extends cdktf.TerraformMetaArguments {
    /**
     * The name of the database containing the current or future file formats on which to grant privileges.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/file_format_grant.html#database_name FileFormatGrant#database_name}
     *
     * @stability stable
     */
    readonly databaseName: string;
    /**
     * The name of the file format on which to grant privileges immediately (only valid if on_future is false).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/file_format_grant.html#file_format_name FileFormatGrant#file_format_name}
     *
     * @stability stable
     */
    readonly fileFormatName?: string;
    /**
     * When this is set to true and a schema_name is provided, apply this grant on all future file formats in the given schema.
     *
     * When this is true and no schema_name is provided apply this grant on all future file formats in the given database. The file_format_name field must be unset in order to use on_future.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/file_format_grant.html#on_future FileFormatGrant#on_future}
     *
     * @stability stable
     */
    readonly onFuture?: boolean;
    /**
     * The privilege to grant on the current or future file format.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/file_format_grant.html#privilege FileFormatGrant#privilege}
     *
     * @stability stable
     */
    readonly privilege?: string;
    /**
     * Grants privilege to these roles.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/file_format_grant.html#roles FileFormatGrant#roles}
     *
     * @stability stable
     */
    readonly roles?: string[];
    /**
     * The name of the schema containing the current or future file formats on which to grant privileges.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/file_format_grant.html#schema_name FileFormatGrant#schema_name}
     *
     * @stability stable
     */
    readonly schemaName: string;
    /**
     * When this is set to true, allows the recipient role to grant the privileges to other roles.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/file_format_grant.html#with_grant_option FileFormatGrant#with_grant_option}
     *
     * @stability stable
     */
    readonly withGrantOption?: boolean;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/snowflake/r/file_format_grant.html snowflake_file_format_grant}.
 *
 * @stability stable
 */
export declare class FileFormatGrant extends cdktf.TerraformResource {
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/snowflake/r/file_format_grant.html snowflake_file_format_grant} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: FileFormatGrantConfig);
    private _databaseName;
    /**
     * @stability stable
     */
    get databaseName(): string;
    /**
     * @stability stable
     */
    set databaseName(value: string);
    /**
     * @stability stable
     */
    get databaseNameInput(): string;
    private _fileFormatName?;
    /**
     * @stability stable
     */
    get fileFormatName(): string;
    /**
     * @stability stable
     */
    set fileFormatName(value: string);
    /**
     * @stability stable
     */
    resetFileFormatName(): void;
    /**
     * @stability stable
     */
    get fileFormatNameInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _onFuture?;
    /**
     * @stability stable
     */
    get onFuture(): boolean;
    /**
     * @stability stable
     */
    set onFuture(value: boolean);
    /**
     * @stability stable
     */
    resetOnFuture(): void;
    /**
     * @stability stable
     */
    get onFutureInput(): boolean | undefined;
    private _privilege?;
    /**
     * @stability stable
     */
    get privilege(): string;
    /**
     * @stability stable
     */
    set privilege(value: string);
    /**
     * @stability stable
     */
    resetPrivilege(): void;
    /**
     * @stability stable
     */
    get privilegeInput(): string | undefined;
    private _roles?;
    /**
     * @stability stable
     */
    get roles(): string[];
    /**
     * @stability stable
     */
    set roles(value: string[]);
    /**
     * @stability stable
     */
    resetRoles(): void;
    /**
     * @stability stable
     */
    get rolesInput(): string[] | undefined;
    private _schemaName;
    /**
     * @stability stable
     */
    get schemaName(): string;
    /**
     * @stability stable
     */
    set schemaName(value: string);
    /**
     * @stability stable
     */
    get schemaNameInput(): string;
    private _withGrantOption?;
    /**
     * @stability stable
     */
    get withGrantOption(): boolean;
    /**
     * @stability stable
     */
    set withGrantOption(value: boolean);
    /**
     * @stability stable
     */
    resetWithGrantOption(): void;
    /**
     * @stability stable
     */
    get withGrantOptionInput(): boolean | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
