import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface IntegrationGrantConfig extends cdktf.TerraformMetaArguments {
    /**
     * Identifier for the integration; must be unique for your account.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/integration_grant.html#integration_name IntegrationGrant#integration_name}
     *
     * @stability stable
     */
    readonly integrationName: string;
    /**
     * The privilege to grant on the integration.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/integration_grant.html#privilege IntegrationGrant#privilege}
     *
     * @stability stable
     */
    readonly privilege?: string;
    /**
     * Grants privilege to these roles.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/integration_grant.html#roles IntegrationGrant#roles}
     *
     * @stability stable
     */
    readonly roles?: string[];
    /**
     * When this is set to true, allows the recipient role to grant the privileges to other roles.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/integration_grant.html#with_grant_option IntegrationGrant#with_grant_option}
     *
     * @stability stable
     */
    readonly withGrantOption?: boolean;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/snowflake/r/integration_grant.html snowflake_integration_grant}.
 *
 * @stability stable
 */
export declare class IntegrationGrant extends cdktf.TerraformResource {
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/snowflake/r/integration_grant.html snowflake_integration_grant} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: IntegrationGrantConfig);
    /**
     * @stability stable
     */
    get id(): string;
    private _integrationName;
    /**
     * @stability stable
     */
    get integrationName(): string;
    /**
     * @stability stable
     */
    set integrationName(value: string);
    /**
     * @stability stable
     */
    get integrationNameInput(): string;
    private _privilege?;
    /**
     * @stability stable
     */
    get privilege(): string;
    /**
     * @stability stable
     */
    set privilege(value: string);
    /**
     * @stability stable
     */
    resetPrivilege(): void;
    /**
     * @stability stable
     */
    get privilegeInput(): string | undefined;
    private _roles?;
    /**
     * @stability stable
     */
    get roles(): string[];
    /**
     * @stability stable
     */
    set roles(value: string[]);
    /**
     * @stability stable
     */
    resetRoles(): void;
    /**
     * @stability stable
     */
    get rolesInput(): string[] | undefined;
    private _withGrantOption?;
    /**
     * @stability stable
     */
    get withGrantOption(): boolean;
    /**
     * @stability stable
     */
    set withGrantOption(value: boolean);
    /**
     * @stability stable
     */
    resetWithGrantOption(): void;
    /**
     * @stability stable
     */
    get withGrantOptionInput(): boolean | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
