import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface MaterializedViewConfig extends cdktf.TerraformMetaArguments {
    /**
     * Specifies a comment for the view.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/materialized_view.html#comment MaterializedView#comment}
     *
     * @stability stable
     */
    readonly comment?: string;
    /**
     * The database in which to create the view. Don't use the | character.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/materialized_view.html#database MaterializedView#database}
     *
     * @stability stable
     */
    readonly database: string;
    /**
     * Specifies that the view is secure.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/materialized_view.html#is_secure MaterializedView#is_secure}
     *
     * @stability stable
     */
    readonly isSecure?: boolean;
    /**
     * Specifies the identifier for the view; must be unique for the schema in which the view is created.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/materialized_view.html#name MaterializedView#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Overwrites the View if it exists.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/materialized_view.html#or_replace MaterializedView#or_replace}
     *
     * @stability stable
     */
    readonly orReplace?: boolean;
    /**
     * The schema in which to create the view. Don't use the | character.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/materialized_view.html#schema MaterializedView#schema}
     *
     * @stability stable
     */
    readonly schema: string;
    /**
     * Specifies the query used to create the view.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/materialized_view.html#statement MaterializedView#statement}
     *
     * @stability stable
     */
    readonly statement: string;
    /**
     * The warehouse name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/materialized_view.html#warehouse MaterializedView#warehouse}
     *
     * @stability stable
     */
    readonly warehouse: string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/snowflake/r/materialized_view.html snowflake_materialized_view}.
 *
 * @stability stable
 */
export declare class MaterializedView extends cdktf.TerraformResource {
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/snowflake/r/materialized_view.html snowflake_materialized_view} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: MaterializedViewConfig);
    private _comment?;
    /**
     * @stability stable
     */
    get comment(): string;
    /**
     * @stability stable
     */
    set comment(value: string);
    /**
     * @stability stable
     */
    resetComment(): void;
    /**
     * @stability stable
     */
    get commentInput(): string | undefined;
    private _database;
    /**
     * @stability stable
     */
    get database(): string;
    /**
     * @stability stable
     */
    set database(value: string);
    /**
     * @stability stable
     */
    get databaseInput(): string;
    /**
     * @stability stable
     */
    get id(): string;
    private _isSecure?;
    /**
     * @stability stable
     */
    get isSecure(): boolean;
    /**
     * @stability stable
     */
    set isSecure(value: boolean);
    /**
     * @stability stable
     */
    resetIsSecure(): void;
    /**
     * @stability stable
     */
    get isSecureInput(): boolean | undefined;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _orReplace?;
    /**
     * @stability stable
     */
    get orReplace(): boolean;
    /**
     * @stability stable
     */
    set orReplace(value: boolean);
    /**
     * @stability stable
     */
    resetOrReplace(): void;
    /**
     * @stability stable
     */
    get orReplaceInput(): boolean | undefined;
    private _schema;
    /**
     * @stability stable
     */
    get schema(): string;
    /**
     * @stability stable
     */
    set schema(value: string);
    /**
     * @stability stable
     */
    get schemaInput(): string;
    private _statement;
    /**
     * @stability stable
     */
    get statement(): string;
    /**
     * @stability stable
     */
    set statement(value: string);
    /**
     * @stability stable
     */
    get statementInput(): string;
    private _warehouse;
    /**
     * @stability stable
     */
    get warehouse(): string;
    /**
     * @stability stable
     */
    set warehouse(value: string);
    /**
     * @stability stable
     */
    get warehouseInput(): string;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
