import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface TableConfig extends cdktf.TerraformMetaArguments {
    /**
     * Specifies whether to enable change tracking on the table. Default false.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/table.html#change_tracking Table#change_tracking}
     *
     * @stability stable
     */
    readonly changeTracking?: boolean;
    /**
     * A list of one or more table columns/expressions to be used as clustering key(s) for the table.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/table.html#cluster_by Table#cluster_by}
     *
     * @stability stable
     */
    readonly clusterBy?: string[];
    /**
     * Specifies a comment for the table.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/table.html#comment Table#comment}
     *
     * @stability stable
     */
    readonly comment?: string;
    /**
     * Specifies the retention period for the table so that Time Travel actions (SELECT, CLONE, UNDROP) can be performed on historical data in the table.
     *
     * Default value is 1, if you wish to inherit the parent schema setting then pass in the schema attribute to this argument.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/table.html#data_retention_days Table#data_retention_days}
     *
     * @stability stable
     */
    readonly dataRetentionDays?: number;
    /**
     * The database in which to create the table.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/table.html#database Table#database}
     *
     * @stability stable
     */
    readonly database: string;
    /**
     * Specifies the identifier for the table;
     *
     * must be unique for the database and schema in which the table is created.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/table.html#name Table#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * The schema in which to create the table.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/table.html#schema Table#schema}
     *
     * @stability stable
     */
    readonly schema: string;
    /**
     * column block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/table.html#column Table#column}
     *
     * @stability stable
     */
    readonly column: TableColumn[];
    /**
     * primary_key block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/table.html#primary_key Table#primary_key}
     *
     * @stability stable
     */
    readonly primaryKey?: TablePrimaryKey[];
}
/**
 * @stability stable
 */
export interface TableColumn {
    /**
     * Column comment.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/table.html#comment Table#comment}
     *
     * @stability stable
     */
    readonly comment?: string;
    /**
     * Column name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/table.html#name Table#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Whether this column can contain null values.
     *
     * **Note**: Depending on your Snowflake version, the default value will not suffice if this column is used in a primary key constraint.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/table.html#nullable Table#nullable}
     *
     * @stability stable
     */
    readonly nullable?: boolean;
    /**
     * Column type, e.g. VARIANT.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/table.html#type Table#type}
     *
     * @stability stable
     */
    readonly type: string;
}
/**
 * @stability stable
 */
export interface TablePrimaryKey {
    /**
     * Columns to use in primary key.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/table.html#keys Table#keys}
     *
     * @stability stable
     */
    readonly keys: string[];
    /**
     * Name of constraint.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/table.html#name Table#name}
     *
     * @stability stable
     */
    readonly name?: string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/snowflake/r/table.html snowflake_table}.
 *
 * @stability stable
 */
export declare class Table extends cdktf.TerraformResource {
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/snowflake/r/table.html snowflake_table} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: TableConfig);
    private _changeTracking?;
    /**
     * @stability stable
     */
    get changeTracking(): boolean;
    /**
     * @stability stable
     */
    set changeTracking(value: boolean);
    /**
     * @stability stable
     */
    resetChangeTracking(): void;
    /**
     * @stability stable
     */
    get changeTrackingInput(): boolean | undefined;
    private _clusterBy?;
    /**
     * @stability stable
     */
    get clusterBy(): string[];
    /**
     * @stability stable
     */
    set clusterBy(value: string[]);
    /**
     * @stability stable
     */
    resetClusterBy(): void;
    /**
     * @stability stable
     */
    get clusterByInput(): string[] | undefined;
    private _comment?;
    /**
     * @stability stable
     */
    get comment(): string;
    /**
     * @stability stable
     */
    set comment(value: string);
    /**
     * @stability stable
     */
    resetComment(): void;
    /**
     * @stability stable
     */
    get commentInput(): string | undefined;
    private _dataRetentionDays?;
    /**
     * @stability stable
     */
    get dataRetentionDays(): number;
    /**
     * @stability stable
     */
    set dataRetentionDays(value: number);
    /**
     * @stability stable
     */
    resetDataRetentionDays(): void;
    /**
     * @stability stable
     */
    get dataRetentionDaysInput(): number | undefined;
    private _database;
    /**
     * @stability stable
     */
    get database(): string;
    /**
     * @stability stable
     */
    set database(value: string);
    /**
     * @stability stable
     */
    get databaseInput(): string;
    /**
     * @stability stable
     */
    get id(): string;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    /**
     * @stability stable
     */
    get owner(): string;
    private _schema;
    /**
     * @stability stable
     */
    get schema(): string;
    /**
     * @stability stable
     */
    set schema(value: string);
    /**
     * @stability stable
     */
    get schemaInput(): string;
    private _column;
    /**
     * @stability stable
     */
    get column(): TableColumn[];
    /**
     * @stability stable
     */
    set column(value: TableColumn[]);
    /**
     * @stability stable
     */
    get columnInput(): TableColumn[];
    private _primaryKey?;
    /**
     * @stability stable
     */
    get primaryKey(): TablePrimaryKey[];
    /**
     * @stability stable
     */
    set primaryKey(value: TablePrimaryKey[]);
    /**
     * @stability stable
     */
    resetPrimaryKey(): void;
    /**
     * @stability stable
     */
    get primaryKeyInput(): TablePrimaryKey[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
