import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface TaskConfig extends cdktf.TerraformMetaArguments {
    /**
     * Specifies the predecessor task in the same database and schema of the current task.
     *
     * When a run of the predecessor task finishes successfully, it triggers this task (after a brief lag).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/task.html#after Task#after}
     *
     * @stability stable
     */
    readonly after?: string;
    /**
     * Specifies a comment for the task.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/task.html#comment Task#comment}
     *
     * @stability stable
     */
    readonly comment?: string;
    /**
     * The database in which to create the task.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/task.html#database Task#database}
     *
     * @stability stable
     */
    readonly database: string;
    /**
     * Specifies if the task should be started (enabled) after creation or should remain suspended (default).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/task.html#enabled Task#enabled}
     *
     * @stability stable
     */
    readonly enabled?: boolean;
    /**
     * Specifies the identifier for the task;
     *
     * must be unique for the database and schema in which the task is created.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/task.html#name Task#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * The schedule for periodically running the task. This can be a cron or interval in minutes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/task.html#schedule Task#schedule}
     *
     * @stability stable
     */
    readonly schedule?: string;
    /**
     * The schema in which to create the task.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/task.html#schema Task#schema}
     *
     * @stability stable
     */
    readonly schema: string;
    /**
     * Specifies session parameters to set for the session when the task runs. A task supports all session parameters.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/task.html#session_parameters Task#session_parameters}
     *
     * @stability stable
     */
    readonly sessionParameters?: {
        [key: string]: string;
    };
    /**
     * Any single SQL statement, or a call to a stored procedure, executed when the task runs.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/task.html#sql_statement Task#sql_statement}
     *
     * @stability stable
     */
    readonly sqlStatement: string;
    /**
     * Specifies the time limit on a single run of the task before it times out (in milliseconds).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/task.html#user_task_timeout_ms Task#user_task_timeout_ms}
     *
     * @stability stable
     */
    readonly userTaskTimeoutMs?: number;
    /**
     * The warehouse the task will use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/task.html#warehouse Task#warehouse}
     *
     * @stability stable
     */
    readonly warehouse: string;
    /**
     * Specifies a Boolean SQL expression; multiple conditions joined with AND/OR are supported.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/task.html#when Task#when}
     *
     * @stability stable
     */
    readonly when?: string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/snowflake/r/task.html snowflake_task}.
 *
 * @stability stable
 */
export declare class Task extends cdktf.TerraformResource {
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/snowflake/r/task.html snowflake_task} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: TaskConfig);
    private _after?;
    /**
     * @stability stable
     */
    get after(): string;
    /**
     * @stability stable
     */
    set after(value: string);
    /**
     * @stability stable
     */
    resetAfter(): void;
    /**
     * @stability stable
     */
    get afterInput(): string | undefined;
    private _comment?;
    /**
     * @stability stable
     */
    get comment(): string;
    /**
     * @stability stable
     */
    set comment(value: string);
    /**
     * @stability stable
     */
    resetComment(): void;
    /**
     * @stability stable
     */
    get commentInput(): string | undefined;
    private _database;
    /**
     * @stability stable
     */
    get database(): string;
    /**
     * @stability stable
     */
    set database(value: string);
    /**
     * @stability stable
     */
    get databaseInput(): string;
    private _enabled?;
    /**
     * @stability stable
     */
    get enabled(): boolean;
    /**
     * @stability stable
     */
    set enabled(value: boolean);
    /**
     * @stability stable
     */
    resetEnabled(): void;
    /**
     * @stability stable
     */
    get enabledInput(): boolean | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _schedule?;
    /**
     * @stability stable
     */
    get schedule(): string;
    /**
     * @stability stable
     */
    set schedule(value: string);
    /**
     * @stability stable
     */
    resetSchedule(): void;
    /**
     * @stability stable
     */
    get scheduleInput(): string | undefined;
    private _schema;
    /**
     * @stability stable
     */
    get schema(): string;
    /**
     * @stability stable
     */
    set schema(value: string);
    /**
     * @stability stable
     */
    get schemaInput(): string;
    private _sessionParameters?;
    /**
     * @stability stable
     */
    get sessionParameters(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set sessionParameters(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetSessionParameters(): void;
    /**
     * @stability stable
     */
    get sessionParametersInput(): {
        [key: string]: string;
    } | undefined;
    private _sqlStatement;
    /**
     * @stability stable
     */
    get sqlStatement(): string;
    /**
     * @stability stable
     */
    set sqlStatement(value: string);
    /**
     * @stability stable
     */
    get sqlStatementInput(): string;
    private _userTaskTimeoutMs?;
    /**
     * @stability stable
     */
    get userTaskTimeoutMs(): number;
    /**
     * @stability stable
     */
    set userTaskTimeoutMs(value: number);
    /**
     * @stability stable
     */
    resetUserTaskTimeoutMs(): void;
    /**
     * @stability stable
     */
    get userTaskTimeoutMsInput(): number | undefined;
    private _warehouse;
    /**
     * @stability stable
     */
    get warehouse(): string;
    /**
     * @stability stable
     */
    set warehouse(value: string);
    /**
     * @stability stable
     */
    get warehouseInput(): string;
    private _when?;
    /**
     * @stability stable
     */
    get when(): string;
    /**
     * @stability stable
     */
    set when(value: string);
    /**
     * @stability stable
     */
    resetWhen(): void;
    /**
     * @stability stable
     */
    get whenInput(): string | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
