import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface ViewConfig extends cdktf.TerraformMetaArguments {
    /**
     * Specifies a comment for the view.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/view.html#comment View#comment}
     *
     * @stability stable
     */
    readonly comment?: string;
    /**
     * The database in which to create the view. Don't use the | character.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/view.html#database View#database}
     *
     * @stability stable
     */
    readonly database: string;
    /**
     * Specifies that the view is secure.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/view.html#is_secure View#is_secure}
     *
     * @stability stable
     */
    readonly isSecure?: boolean;
    /**
     * Specifies the identifier for the view;
     *
     * must be unique for the schema in which the view is created. Don't use the | character.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/view.html#name View#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Overwrites the View if it exists.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/view.html#or_replace View#or_replace}
     *
     * @stability stable
     */
    readonly orReplace?: boolean;
    /**
     * The schema in which to create the view. Don't use the | character.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/view.html#schema View#schema}
     *
     * @stability stable
     */
    readonly schema: string;
    /**
     * Specifies the query used to create the view.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/view.html#statement View#statement}
     *
     * @stability stable
     */
    readonly statement: string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/snowflake/r/view.html snowflake_view}.
 *
 * @stability stable
 */
export declare class View extends cdktf.TerraformResource {
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/snowflake/r/view.html snowflake_view} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: ViewConfig);
    private _comment?;
    /**
     * @stability stable
     */
    get comment(): string;
    /**
     * @stability stable
     */
    set comment(value: string);
    /**
     * @stability stable
     */
    resetComment(): void;
    /**
     * @stability stable
     */
    get commentInput(): string | undefined;
    private _database;
    /**
     * @stability stable
     */
    get database(): string;
    /**
     * @stability stable
     */
    set database(value: string);
    /**
     * @stability stable
     */
    get databaseInput(): string;
    /**
     * @stability stable
     */
    get id(): string;
    private _isSecure?;
    /**
     * @stability stable
     */
    get isSecure(): boolean;
    /**
     * @stability stable
     */
    set isSecure(value: boolean);
    /**
     * @stability stable
     */
    resetIsSecure(): void;
    /**
     * @stability stable
     */
    get isSecureInput(): boolean | undefined;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _orReplace?;
    /**
     * @stability stable
     */
    get orReplace(): boolean;
    /**
     * @stability stable
     */
    set orReplace(value: boolean);
    /**
     * @stability stable
     */
    resetOrReplace(): void;
    /**
     * @stability stable
     */
    get orReplaceInput(): boolean | undefined;
    private _schema;
    /**
     * @stability stable
     */
    get schema(): string;
    /**
     * @stability stable
     */
    set schema(value: string);
    /**
     * @stability stable
     */
    get schemaInput(): string;
    private _statement;
    /**
     * @stability stable
     */
    get statement(): string;
    /**
     * @stability stable
     */
    set statement(value: string);
    /**
     * @stability stable
     */
    get statementInput(): string;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
