import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface WarehouseConfig extends cdktf.TerraformMetaArguments {
    /**
     * Specifies whether to automatically resume a warehouse when a SQL statement (e.g. query) is submitted to it.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/warehouse.html#auto_resume Warehouse#auto_resume}
     *
     * @stability stable
     */
    readonly autoResume?: boolean;
    /**
     * Specifies the number of seconds of inactivity after which a warehouse is automatically suspended.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/warehouse.html#auto_suspend Warehouse#auto_suspend}
     *
     * @stability stable
     */
    readonly autoSuspend?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/warehouse.html#comment Warehouse#comment}.
     *
     * @stability stable
     */
    readonly comment?: string;
    /**
     * Specifies whether the warehouse is created initially in the ‘Suspended’ state.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/warehouse.html#initially_suspended Warehouse#initially_suspended}
     *
     * @stability stable
     */
    readonly initiallySuspended?: boolean;
    /**
     * Specifies the maximum number of server clusters for the warehouse.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/warehouse.html#max_cluster_count Warehouse#max_cluster_count}
     *
     * @stability stable
     */
    readonly maxClusterCount?: number;
    /**
     * Object parameter that specifies the concurrency level for SQL statements (i.e. queries and DML) executed by a warehouse.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/warehouse.html#max_concurrency_level Warehouse#max_concurrency_level}
     *
     * @stability stable
     */
    readonly maxConcurrencyLevel?: number;
    /**
     * Specifies the minimum number of server clusters for the warehouse (only applies to multi-cluster warehouses).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/warehouse.html#min_cluster_count Warehouse#min_cluster_count}
     *
     * @stability stable
     */
    readonly minClusterCount?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/warehouse.html#name Warehouse#name}.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Specifies the name of a resource monitor that is explicitly assigned to the warehouse.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/warehouse.html#resource_monitor Warehouse#resource_monitor}
     *
     * @stability stable
     */
    readonly resourceMonitor?: string;
    /**
     * Specifies the policy for automatically starting and shutting down clusters in a multi-cluster warehouse running in Auto-scale mode.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/warehouse.html#scaling_policy Warehouse#scaling_policy}
     *
     * @stability stable
     */
    readonly scalingPolicy?: string;
    /**
     * Object parameter that specifies the time, in seconds, a SQL statement (query, DDL, DML, etc.) can be queued on a warehouse before it is canceled by the system.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/warehouse.html#statement_queued_timeout_in_seconds Warehouse#statement_queued_timeout_in_seconds}
     *
     * @stability stable
     */
    readonly statementQueuedTimeoutInSeconds?: number;
    /**
     * Specifies the time, in seconds, after which a running SQL statement (query, DDL, DML, etc.) is canceled by the system.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/warehouse.html#statement_timeout_in_seconds Warehouse#statement_timeout_in_seconds}
     *
     * @stability stable
     */
    readonly statementTimeoutInSeconds?: number;
    /**
     * Specifies whether the warehouse, after being resized, waits for all the servers to provision before executing any queued or new queries.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/warehouse.html#wait_for_provisioning Warehouse#wait_for_provisioning}
     *
     * @stability stable
     */
    readonly waitForProvisioning?: boolean;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/warehouse.html#warehouse_size Warehouse#warehouse_size}.
     *
     * @stability stable
     */
    readonly warehouseSize?: string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/snowflake/r/warehouse.html snowflake_warehouse}.
 *
 * @stability stable
 */
export declare class Warehouse extends cdktf.TerraformResource {
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/snowflake/r/warehouse.html snowflake_warehouse} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: WarehouseConfig);
    private _autoResume?;
    /**
     * @stability stable
     */
    get autoResume(): boolean;
    /**
     * @stability stable
     */
    set autoResume(value: boolean);
    /**
     * @stability stable
     */
    resetAutoResume(): void;
    /**
     * @stability stable
     */
    get autoResumeInput(): boolean | undefined;
    private _autoSuspend?;
    /**
     * @stability stable
     */
    get autoSuspend(): number;
    /**
     * @stability stable
     */
    set autoSuspend(value: number);
    /**
     * @stability stable
     */
    resetAutoSuspend(): void;
    /**
     * @stability stable
     */
    get autoSuspendInput(): number | undefined;
    private _comment?;
    /**
     * @stability stable
     */
    get comment(): string;
    /**
     * @stability stable
     */
    set comment(value: string);
    /**
     * @stability stable
     */
    resetComment(): void;
    /**
     * @stability stable
     */
    get commentInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _initiallySuspended?;
    /**
     * @stability stable
     */
    get initiallySuspended(): boolean;
    /**
     * @stability stable
     */
    set initiallySuspended(value: boolean);
    /**
     * @stability stable
     */
    resetInitiallySuspended(): void;
    /**
     * @stability stable
     */
    get initiallySuspendedInput(): boolean | undefined;
    private _maxClusterCount?;
    /**
     * @stability stable
     */
    get maxClusterCount(): number;
    /**
     * @stability stable
     */
    set maxClusterCount(value: number);
    /**
     * @stability stable
     */
    resetMaxClusterCount(): void;
    /**
     * @stability stable
     */
    get maxClusterCountInput(): number | undefined;
    private _maxConcurrencyLevel?;
    /**
     * @stability stable
     */
    get maxConcurrencyLevel(): number;
    /**
     * @stability stable
     */
    set maxConcurrencyLevel(value: number);
    /**
     * @stability stable
     */
    resetMaxConcurrencyLevel(): void;
    /**
     * @stability stable
     */
    get maxConcurrencyLevelInput(): number | undefined;
    private _minClusterCount?;
    /**
     * @stability stable
     */
    get minClusterCount(): number;
    /**
     * @stability stable
     */
    set minClusterCount(value: number);
    /**
     * @stability stable
     */
    resetMinClusterCount(): void;
    /**
     * @stability stable
     */
    get minClusterCountInput(): number | undefined;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _resourceMonitor?;
    /**
     * @stability stable
     */
    get resourceMonitor(): string;
    /**
     * @stability stable
     */
    set resourceMonitor(value: string);
    /**
     * @stability stable
     */
    resetResourceMonitor(): void;
    /**
     * @stability stable
     */
    get resourceMonitorInput(): string | undefined;
    private _scalingPolicy?;
    /**
     * @stability stable
     */
    get scalingPolicy(): string;
    /**
     * @stability stable
     */
    set scalingPolicy(value: string);
    /**
     * @stability stable
     */
    resetScalingPolicy(): void;
    /**
     * @stability stable
     */
    get scalingPolicyInput(): string | undefined;
    private _statementQueuedTimeoutInSeconds?;
    /**
     * @stability stable
     */
    get statementQueuedTimeoutInSeconds(): number;
    /**
     * @stability stable
     */
    set statementQueuedTimeoutInSeconds(value: number);
    /**
     * @stability stable
     */
    resetStatementQueuedTimeoutInSeconds(): void;
    /**
     * @stability stable
     */
    get statementQueuedTimeoutInSecondsInput(): number | undefined;
    private _statementTimeoutInSeconds?;
    /**
     * @stability stable
     */
    get statementTimeoutInSeconds(): number;
    /**
     * @stability stable
     */
    set statementTimeoutInSeconds(value: number);
    /**
     * @stability stable
     */
    resetStatementTimeoutInSeconds(): void;
    /**
     * @stability stable
     */
    get statementTimeoutInSecondsInput(): number | undefined;
    private _waitForProvisioning?;
    /**
     * @stability stable
     */
    get waitForProvisioning(): boolean;
    /**
     * @stability stable
     */
    set waitForProvisioning(value: boolean);
    /**
     * @stability stable
     */
    resetWaitForProvisioning(): void;
    /**
     * @stability stable
     */
    get waitForProvisioningInput(): boolean | undefined;
    private _warehouseSize?;
    /**
     * @stability stable
     */
    get warehouseSize(): string;
    /**
     * @stability stable
     */
    set warehouseSize(value: string);
    /**
     * @stability stable
     */
    resetWarehouseSize(): void;
    /**
     * @stability stable
     */
    get warehouseSizeInput(): string | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
